## -*- mode: tcl -*-
# Copyright (c) 2007 The Foundry Visionmongers Ltd.  All Rights Reserved.

# Read a .chan file into the current node which should be a Camera or
# Axis.

# read data from a camera chan file:
# format is: FRAME TX TY TZ RX RY RZ VFOV
# If file contains fewer columns than only those columns are read
# 
# !!!adapted for max2nuke support v02


proc import_chan_file {filename} {

  set not_camera ![exists this.vaperture]

  if !$not_camera {
      set va [value vaperture]
  }

  catch {animation translate.x clear}
  catch {animation translate.y clear}
  catch {animation translate.z clear}
  catch {animation rotate.x clear}
  catch {animation rotate.y clear}
  catch {animation rotate.z clear}
  catch {animation focal clear}

  set f [open $filename r]
  set n 0
  while {[gets $f line]>=0} {
      if {[llength $line] < 4} continue
      incr n
      set fr [lindex $line 0]
      setkey translate.x $fr [lindex $line 1]
      setkey translate.y $fr [lindex $line 2]
      setkey translate.z $fr [lindex $line 3]
      if {[llength $line] < 7} continue
      setkey rotate.x $fr [lindex $line 4]
      setkey rotate.y $fr [lindex $line 5]
      setkey rotate.z $fr [lindex $line 6]

	if {[llength $line] < 8} continue

      if $not_camera continue
      setkey focal $fr [expr ($va / 2.0) / (tan( [lindex $line 7] / 2.0 / 180.0*3.14159))]
	
      if {[llength $line] < 9} continue
	
	knob this.haperture [lindex $line 8]
	knob this.vaperture [lindex $line 9]

	if $not_camera continue
	setkey focal $fr [expr ([value vaperture] / 2.0) / (tan( [lindex $line 7] / 2.0 / 180.0*3.14159))]


  }
  close $f

  # Turn off selectable flag so user doesn't destroy animation accidently:
  catch {knob selected false; knob selectable false}

  # Save the filename into the node's label so user knows
  # where data came from.  This concats onto the existing label currently.
  catch {knob label [file tail $filename]}

  return "Loaded $n frames."
}

